@@ -3,7 +3,7 @@ extern crate lazy_static;
 extern crate pathfinding;
 extern crate rand;
 
-use pathfinding::{astar, idastar};
+use pathfinding::prelude::{astar, idastar};
 use rand::os::OsRng;
 use rand::Rng;
 use std::time::Instant;
@@ -130,8 +130,8 @@ impl Game {
             .unwrap()
             .0 as u8;
         let mut game = Game {
-            positions: positions,
-            hole_idx: hole_idx,
+            positions,
+            hole_idx,
             weight: 0,
         };
         game.weight = (0..LIMIT as u8)
