@@ -1,7 +1,17 @@
+//! Compute the maximum flow that can go through a directed graph using the
+//! [Edmonds Karp algorithm](https://en.wikipedia.org/wiki/Edmonds–Karp_algorithm).
+//!
+//! This module contains several functions helping compute the flow on a given
+//! graph, as well as a structure which allows iterative modifications of the
+//! network. When the network is modified, the flow is recomputed and tries to
+//! take advantage of computations already performed on unchanged or augmented
+//! edges.
+
 use num_traits::{Bounded, Signed, Zero};
 use std::collections::{BTreeMap, HashMap, VecDeque};
 use std::hash::Hash;
-use super::{bfs, Matrix};
+use super::bfs::bfs;
+use super::matrix::Matrix;
 
 /// Type alias for Edmonds-Karp result.
 pub type EKFlows<N, C> = (Vec<((N, N), C)>, C);
@@ -329,9 +339,9 @@ impl<C: Copy + Zero + Signed + Eq + Ord + Bounded> EdmondsKarp<C> for SparseCapa
         assert!(sink < size, "sink is greater or equal than size");
         SparseCapacity {
             common: Common {
-                size: size,
-                source: source,
-                sink: sink,
+                size,
+                source,
+                sink,
                 total_capacity: Zero::zero(),
                 detailed_flows: true,
             },
@@ -444,9 +454,9 @@ impl<C: Copy + Zero + Signed + Ord + Bounded> EdmondsKarp<C> for DenseCapacity<C
         assert!(sink < size, "sink is greater or equal than size");
         DenseCapacity {
             common: Common {
-                size: size,
-                source: source,
-                sink: sink,
+                size,
+                source,
+                sink,
                 total_capacity: Zero::zero(),
                 detailed_flows: true,
             },
@@ -465,9 +475,9 @@ impl<C: Copy + Zero + Signed + Ord + Bounded> EdmondsKarp<C> for DenseCapacity<C
         assert!(sink < size, "sink is greater or equal than matrix side");
         DenseCapacity {
             common: Common {
-                size: size,
-                source: source,
-                sink: sink,
+                size,
+                source,
+                sink,
                 total_capacity: Zero::zero(),
                 detailed_flows: true,
             },
