@@ -1,3 +1,5 @@
+//! Matrix of an arbitrary type and utilities to rotate, transpose, etc.
+
 extern crate itertools;
 
 use num_traits::Signed;
@@ -23,8 +25,8 @@ impl<C: Clone> Matrix<C> {
         let mut v = Vec::with_capacity(rows * columns);
         v.resize(rows * columns, value);
         Matrix {
-            rows: rows,
-            columns: columns,
+            rows,
+            columns,
             data: v,
         }
     }
@@ -147,8 +149,8 @@ impl<C> Matrix<C> {
             "length of vector does not correspond to announced dimensions"
         );
         Matrix {
-            rows: rows,
-            columns: columns,
+            rows,
+            columns,
             data: values,
         }
     }
